@@ -30,23 +30,11 @@ fi
 RSTFILES=(
   ". lazarusidestrconsts lazaruside"
   ". debuggerstrconst"
-  ". gdbmidebugger"
-  ". gdbmiserverdebugger"
-  "components/codetools codetoolsstrconsts"
-  "components/tdbf registerdbf"
-  "components/turbopower_ipro ipconst"
-  "components/turbopower_ipro iputils"
   "components/lazreport/samples/editor maincalleditor calleditorwithpkg"
-  "components/memds frmselectdataset"
-  "components/printers/design ideprinting"
-  "components/projecttemplates projecttemplates"
-  "components/projecttemplates frmtemplatevariables"
-  "components/projecttemplates idetemplateproject"
-  "tools/lazdatadesktop lazdatadeskstr lazdatadesktop"
   "doceditor lazdemsg lazde"
   "examples/lazresexplorer reconstsunit resexplorer"
-  "lcl lclstrconsts"
-)  
+  "tools/lazdatadesktop lazdatadeskstr lazdatadesktop"
+)
 
 set -x
 
